# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.cohort_detail_schema import CohortDetailSchema  # noqa: E501


class TestCohortDetailSchema(unittest.TestCase):
    """CohortDetailSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CohortDetailSchema:
        """Test CohortDetailSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `CohortDetailSchema`
        """
        model = CohortDetailSchema()  # noqa: E501
        if include_optional:
            return CohortDetailSchema(
                id = 56,
                name = '',
                slug = '',
                description = '',
                created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                sample_files = [
                    haplohub.models.sample_file_schema.SampleFileSchema(
                        id = 56, 
                        filename = '', 
                        file_size = 56, 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ]
            )
        else:
            return CohortDetailSchema(
                name = '',
                slug = '',
                description = '',
                sample_files = [
                    haplohub.models.sample_file_schema.SampleFileSchema(
                        id = 56, 
                        filename = '', 
                        file_size = 56, 
                        created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ],
        )
        """

    def testCohortDetailSchema(self):
        """Test CohortDetailSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
