# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest


class TestReportType(unittest.TestCase):
    """ReportType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testReportType(self):
        """Test ReportType"""
        # inst = ReportType()


if __name__ == "__main__":
    unittest.main()
