# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from datetime import datetime
from typing import Optional

from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr, constr


class CohortSchema(BaseModel):
    """
    CohortSchema
    """

    id: Optional[StrictInt] = None
    name: constr(strict=True, max_length=255) = Field(...)
    read_only: Optional[StrictBool] = False
    description: StrictStr = Field(...)
    created: Optional[datetime] = None
    modified: Optional[datetime] = None
    __properties = ["id", "name", "read_only", "description", "created", "modified"]

    class Config:
        """Pydantic configuration"""

        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CohortSchema:
        """Create an instance of CohortSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True, exclude={}, exclude_none=True)
        # set to None if id (nullable) is None
        # and __fields_set__ contains the field
        if self.id is None and "id" in self.__fields_set__:
            _dict["id"] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CohortSchema:
        """Create an instance of CohortSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return CohortSchema.parse_obj(obj)

        _obj = CohortSchema.parse_obj(
            {
                "id": obj.get("id"),
                "name": obj.get("name"),
                "read_only": obj.get("read_only") if obj.get("read_only") is not None else False,
                "description": obj.get("description"),
                "created": obj.get("created"),
                "modified": obj.get("modified"),
            }
        )
        return _obj
