# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.workflow_run_schema import WorkflowRunSchema  # noqa: E501


class TestWorkflowRunSchema(unittest.TestCase):
    """WorkflowRunSchema unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WorkflowRunSchema:
        """Test WorkflowRunSchema
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `WorkflowRunSchema`
        """
        model = WorkflowRunSchema()  # noqa: E501
        if include_optional:
            return WorkflowRunSchema(
                triggered_by = haplohub.models.user_schema.UserSchema(
                    id = '', ),
                id = 56,
                workflow_id = '',
                workflow_type = '',
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f')
            )
        else:
            return WorkflowRunSchema(
                workflow_id = '',
                workflow_type = '',
                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
        )
        """

    def testWorkflowRunSchema(self):
        """Test WorkflowRunSchema"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
