# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.models.create_report_template_request import CreateReportTemplateRequest  # noqa: E501


class TestCreateReportTemplateRequest(unittest.TestCase):
    """CreateReportTemplateRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> CreateReportTemplateRequest:
        """Test CreateReportTemplateRequest
        include_option is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `CreateReportTemplateRequest`
        """
        model = CreateReportTemplateRequest()  # noqa: E501
        if include_optional:
            return CreateReportTemplateRequest(
                name = '',
                report_type = 'text'
            )
        else:
            return CreateReportTemplateRequest(
                name = '',
                report_type = 'text',
        )
        """

    def testCreateReportTemplateRequest(self):
        """Test CreateReportTemplateRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()
