# coding: utf-8

"""
HaploHub API

No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

The version of the OpenAPI document: 1.0
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from haplohub.api.prediction_api import PredictionApi  # noqa: E501


class TestPredictionApi(unittest.TestCase):
    """PredictionApi unit test stubs"""

    def setUp(self) -> None:
        self.api = PredictionApi()

    def tearDown(self) -> None:
        pass

    def test_get_prediction(self) -> None:
        """Test case for get_prediction

        Get prediction  # noqa: E501
        """
        pass

    def test_get_prediction_results(self) -> None:
        """Test case for get_prediction_results

        Get prediction results  # noqa: E501
        """
        pass

    def test_list_predictions(self) -> None:
        """Test case for list_predictions

        List predictions  # noqa: E501
        """
        pass

    def test_run_prediction(self) -> None:
        """Test case for run_prediction

        Run prediction  # noqa: E501
        """
        pass


if __name__ == "__main__":
    unittest.main()
